@@ -3,10 +3,10 @@ import yarl
 import numpy as np
 from deeplabel.label.gallery.images import Image
 
-def url_to_name(url):
+def url_to_name(url:str):
     return yarl.URL(url).name
 
-def url_to_extension(url):
+def url_to_extension(url:str):
     """Return file's extension from url
     eg.
         .txt, .png, .jpg
@@ -21,11 +21,11 @@ def image_to_name(image:Image):
     """
     return image.image_id+url_to_extension(image.image_url)
 
-def pascal_voc_color_map(N=256, normalized=False):
+def pascal_voc_color_map(N:int=256, normalized:bool=False):
     """ Copied from: https://gist.github.com/wllhf/a4533e0adebe57e3ed06d4b50c8419ae
     And tested by doing Image.open('<some img from pascal dataset>').getpalette()
     """
-    def bitget(byteval, idx):
+    def bitget(byteval:int, idx:int):
         return ((byteval & (1 << idx)) != 0)
 
     dtype = 'float32' if normalized else 'uint8'
